Changes
=======

0.3.1 2011-11-16
----------------
- Rename the module to avoid collisions with the jslint python wrapper project

0.3 2011-11-16
--------------
- Simplify the module by moving the main file into the root directory
- Remove the reformat function
